more.transaction: SQLAlchemy and ZODB integration for Morepath
==============================================================

more.transaction builds on the transaction_ module to let you
integrate SQLAlchemy or ZODB (or both!) into Morepath_ applications.

See https://github.com/morepath/morepath_sqlalchemy for a demo.

.. _transaction: https://pypi.python.org/pypi/transaction

.. _Morepath: http://morepath.readthedocs.org

Build Status
------------

.. image:: https://travis-ci.org/morepath/more.transaction.svg?branch=master
    :target: https://travis-ci.org/morepath/more.transaction

.. image:: https://coveralls.io/repos/morepath/more.transaction/badge.svg?branch=master
    :target: https://coveralls.io/r/morepath/more.transaction?branch=master
